@@ -1,14 +1,12 @@
 use crate::auth::PrintNannyConfigFile;
-use crate::response::{FlashResponse, Response};
+use crate::response::Response;
 use printnanny_services::config::PrintNannyConfig;
 use rocket::serde::json::Json;
 use rocket::State;
 use rocket_dyn_templates::Template;
 
 #[get("/")]
-fn get_config(
-    config_file: &State<PrintNannyConfigFile>,
-) -> Result<Response, FlashResponse<Template>> {
+fn get_config(config_file: &State<PrintNannyConfigFile>) -> Result<Response, Response> {
     let config = PrintNannyConfig::new(config_file.0.as_deref())?;
     info!("Rendering config {:?}", config);
     Ok(Response::PrintNannyConfig(Json(config)))
